@@ -359,7 +359,7 @@ calmaParseStructure(filename)
     int mfactor;
     int locPolygonCount;
     OFFTYPE filepos;
-    bool was_called;
+    bool was_called = FALSE;
     bool was_initialized;
     bool predefined;
     bool do_flatten;
@@ -610,8 +610,12 @@ calmaParseStructure(filename)
 			(locPolygonCount < CalmaPolygonCount))
 	DBCellEnum(cifReadCellDef, calmaFlattenPolygonFunc, (ClientData)cifReadCellDef);
 
-    DBAdjustLabelsNew(cifReadCellDef, &TiPlaneRect,
-	      (cifCurReadStyle->crs_flags & CRF_NO_RECONNECT_LABELS) ? 1 : 0);
+    /* Because the "label" statement can only match one GDS layer to one magic
+     * layer, then all labels are subject to adjustment to attach them to
+     * something meaningful in the layout.  The "no-reconnect-labels" option
+     * is not useful and has been deprecated.
+     */
+    DBAdjustLabelsNew(cifReadCellDef, &TiPlaneRect);
     DBReComputeBbox(cifReadCellDef);
 
     /* Don't bother to register with DRC if we're going to delete the	*/
@@ -1374,7 +1378,8 @@ calmaFindCell(name, was_called, predefined)
 	     * if the cell is used in a parent before being defined
 	     * then it will cause a core dump.
 	     */
-	     DBReComputeBbox(def);
+	    DBReComputeBbox(def);
+	    if (was_called) *was_called = FALSE;
 	}
 	else
 	{
@@ -1385,9 +1390,9 @@ calmaFindCell(name, was_called, predefined)
 		if (predefined) *predefined = TRUE;
 	    	TxPrintf("Using pre-existing cell definition\n");
 	    }
+	    if (was_called) *was_called = TRUE;
 	}
 	HashSetValue(h, def);
-	if (was_called) *was_called = FALSE;
     }
     else
     {
