@@ -62,7 +62,6 @@ bool esNoAttrs = FALSE;
 bool esHierAP = FALSE;
 bool esMergeDevsA = FALSE;	/* merge devices of equal length */
 bool esMergeDevsC = FALSE;	/* merge devices of equal length & width */
-int esCapAccuracy = 1;
 
 #else
 extern bool esDevNodesOnly;
@@ -70,7 +69,8 @@ extern bool esNoAttrs;
 extern bool esHierAP;
 extern bool esMergeDevsA;
 extern bool esMergeDevsC;
-extern int esCapAccuracy;
+extern char esSpiceDefaultGnd[];
+extern char *esSpiceCapNode;
 #endif
 
 bool esDoSimExtResis = FALSE;
@@ -615,7 +615,7 @@ runexttosim:
     }
 
     /* Read the hierarchical description of the input circuit */
-    if (EFReadFile(inName, FALSE, esDoSimExtResis, FALSE) == FALSE)
+    if (EFReadFile(inName, FALSE, esDoSimExtResis, FALSE, FALSE) == FALSE)
     {
 	EFDone();
 	return /* TCL_ERROR */;
@@ -690,11 +690,10 @@ runexttosim:
 
     EFVisitDevs(simdevVisit, (ClientData)NULL);
     if (flatFlags & EF_FLATCAPS) {
-    	(void) sprintf( esCapFormat, " %%.%dlf\n", esCapAccuracy);
 	EFVisitCaps(simcapVisit, (ClientData) NULL);
     }
     EFVisitResists(simresistVisit, (ClientData) NULL);
-    (void) sprintf( esCapFormat, " GND %%.%dlf\n", esCapAccuracy);
+    esSpiceCapNode = esSpiceDefaultGnd;
     EFVisitNodes(simnodeVisit, (ClientData) NULL);
 
     EFFlatDone(NULL);
@@ -792,7 +791,7 @@ main(argc, argv)
     }
 
     /* Read the hierarchical description of the input circuit */
-    if (EFReadFile(inName, FALSE, esDoSimExtResis, FALSE) == FALSE)
+    if (EFReadFile(inName, FALSE, esDoSimExtResis, FALSE, FALSE) == FALSE)
     {
 	exit(1);
     }
@@ -817,12 +816,10 @@ main(argc, argv)
     }
 
     EFVisitDevs(simdevVisit, (ClientData) NULL);
-    if (flatFlags & EF_FLATCAPS) {
-    	(void) sprintf( esCapFormat, " %%.%dlf\n", esCapAccuracy);
+    if (flatFlags & EF_FLATCAPS)
 	EFVisitCaps(simcapVisit, (ClientData) NULL);
-    }
     EFVisitResists(simresistVisit, (ClientData) NULL);
-    (void) sprintf( esCapFormat, " GND %%.%dlf\n", esCapAccuracy);
+    esSpiceCapNode = esSpiceDefaultGnd;
     EFVisitNodes(simnodeVisit, (ClientData) NULL);
 
     EFFlatDone(NULL);
@@ -922,7 +919,7 @@ simParseArgs(pargc, pargv)
 
 	      if (( t =  ArgStr(&argc, &argv, "cap-accuracy") ) == NULL)
 		goto usage;
-	      esCapAccuracy = atoi(t);
+	      TxPrintf("Cap accuracy option -y is deprecated.\n");
 	      break;
 	      }
 	case 'J':
@@ -1169,22 +1166,28 @@ simdevVisit(dev, hc, scale, trans)
 	}
     }
 
-    if (is_subckt && subnode)
+    if (dev->dev_class != DEV_DIODE && dev->dev_class != DEV_NDIODE &&
+		dev->dev_class != DEV_PDIODE)
     {
-	/* As a general policy on subcircuits supporting extresist, */
-	/* output the subcircuit node as the last port of the	    */
-	/* subcircuit definition.				    */
-	putc(' ', esSimF);
-	simdevSubstrate(hierName, subnode->efnode_name->efnn_hier,
-	             dev->dev_type, 0.0, FALSE, esSimF);
-    }
+	if (is_subckt && subnode)
+	{
+	    /* As a general policy on subcircuits supporting extresist,	*/
+	    /* output the subcircuit node as the last port of the	*/
+	    /* subcircuit definition, *except* for the use of the 'x'	*/
+	    /* device type for diodes.					*/
 
-    /* Support gemini's substrate comparison */
-    else if (esFormat == LBL && subnode)
-    {
-	putc(' ', esSimF);
-	simdevSubstrate(hierName, subnode->efnode_name->efnn_hier,
+	    putc(' ', esSimF);
+	    simdevSubstrate(hierName, subnode->efnode_name->efnn_hier,
 	             dev->dev_type, 0.0, FALSE, esSimF);
+	}
+
+	/* Support gemini's substrate comparison */
+	else if (esFormat == LBL && subnode)
+	{
+	    putc(' ', esSimF);
+	    simdevSubstrate(hierName, subnode->efnode_name->efnn_hier,
+	             dev->dev_type, 0.0, FALSE, esSimF);
+	}
     }
 
     GeoTransRect(trans, &dev->dev_rect, &r);
@@ -1225,6 +1228,12 @@ simdevVisit(dev, hc, scale, trans)
     }
     else if (is_subckt)
     {
+	/* Output source and drain attributes */
+	if (source->dterm_attrs)
+	    fprintf(esSimF, " s=%s", source->dterm_attrs);
+	if ((source != drain) && drain->dterm_attrs)
+	       fprintf(esSimF, " d=%s", drain->dterm_attrs);
+
 	/* Output length, width, and position as attributes */
         fprintf(esSimF, " l=%g w=%g x=%g y=%g",
 		l * scale, w * scale, r.r_xbot * scale, r.r_ybot * scale);
@@ -1523,7 +1532,7 @@ int simcapVisit(hierName1, hierName2, cap)
     EFHNOut(hierName1, esSimF);
     fprintf(esSimF, " ");
     EFHNOut(hierName2, esSimF);
-    fprintf(esSimF, esCapFormat, cap);
+    fprintf(esSimF, " %.1lf\n", cap);
     return 0;
 }
 
@@ -1606,7 +1615,8 @@ int simnodeVisit(node, res, cap)
     {
 	fprintf(esSimF, "C ");
 	EFHNOut(hierName, esSimF);
-	fprintf(esSimF, esCapFormat, cap);
+	fprintf(esSimF, "%s ", esSpiceCapNode);
+	fprintf(esSimF, "%.1f\n", cap);
     }
     if (res > EFResistThreshold)
     {
